@@ -24,6 +24,7 @@
 
 #include "about.h"
 #include "actions.h"
+#include "backend.h"
 #include "color-schemes.h"
 #include "dialogs.h"
 #include "dnd.h"
@@ -158,7 +159,7 @@ static gint create_popup_menu(GtkText *widget, GdkEventButton *event, gpointer d
 		{
 			GtkWidget *popup_menu;
 
-			popup_menu=gnome_popup_menu_new(the_popup_menu);
+			popup_menu=gnome_popup_menu_new(the_main_popup_menu);
 
 			gtk_menu_popup(GTK_MENU(popup_menu), NULL, NULL,
 				NULL, NULL, event->button, event->time);
@@ -215,7 +216,8 @@ void gtranslator_create_main_window(void)
 	gtranslator_config_init();
 
 	/*
-	 * Activate the paned widgets if desired and fill them up with the right positions.
+	 * Activate the paned widgets if desired and set the pane gutter to
+	 *  the right place.
 	 */
 	if(GtrPreferences.show_sidebar)
 	{
@@ -226,7 +228,7 @@ void gtranslator_create_main_window(void)
 	}
 	else
 	{
-		e_paned_set_position(E_PANED(sidebar_pane), 0);
+		e_paned_set_position(E_PANED(sidebar_pane), -1);
 	}
 
 	if(GtrPreferences.show_messages_table)
@@ -238,7 +240,7 @@ void gtranslator_create_main_window(void)
 	}
 	else
 	{
-		e_paned_set_position(E_PANED(table_pane), 0);
+		e_paned_set_position(E_PANED(table_pane), -1);
 	}
 	
 	gtranslator_config_close();
@@ -448,6 +450,11 @@ gint gtranslator_quit(GtkWidget  * widget, GdkEventAny  * e,
 		gtranslator_messages_table_save_state();
 	}
 
+	/*
+	 * Also clean up/free our backend space.
+	 */
+	gtranslator_backend_remove_all_backends();
+
 	/*
 	 * Shutdown our internal learning system.
 	 */
@@ -462,10 +469,9 @@ gint gtranslator_quit(GtkWidget  * widget, GdkEventAny  * e,
 	gtranslator_translator_free(gtranslator_translator);
 
 	/*
-	 * Free any lungering stuff 'round -- free prefs & regex cache.
+	 * Free any lungering stuff 'round -- free prefs.
 	 */
 	gtranslator_preferences_free();
-	gnome_regex_cache_destroy(rxc);
 
 	/*
 	 * Remove any lungering temp. file.
@@ -557,7 +563,7 @@ void gtranslator_application_bar_update(gint pos)
 		 */
 		if ((po->length - po->translated)>0)
 		{
-			guint missya;
+			gint missya;
 			missya = po->length - po->translated;
 			status=g_strdup_printf(_("%s [ %i Untranslated left ]"), _("Untranslated"), missya);
 		} else {
@@ -646,7 +652,10 @@ void gtranslator_translation_changed(GtkWidget  * widget, gpointer useless)
 		     && (msg->status & GTR_MSG_STATUS_FUZZY))
 		{
 		     	gtranslator_message_status_set_fuzzy(msg, FALSE);
-			gtranslator_messages_table_update_message_status(msg);
+			if(GtrPreferences.show_messages_table)
+			{
+				gtranslator_messages_table_update_message_status(msg);
+			}
 			gtranslator_actions_disable_fuzzy_menu_item();
 		}
 	}
@@ -757,6 +766,19 @@ static gint gtranslator_keyhandler(GtkWidget *widget, GdkEventKey *event)
 
 	if(file_opened)
 	{
+		/*
+		 * If we're having a Ctrl+Shift+Arrow Key issue, then respect
+		 *  this to be something another then just Ctrl+Arrow Key.
+		 */
+		if(event->state & GDK_SHIFT_MASK)
+		{
+			return TRUE;
+		}
+
+		/*
+		 * Now handle out "normal" navigation keys consisting out of
+		 *  Ctrl+Arrow Key.
+		 */
 		if(event->state & GDK_CONTROL_MASK)
 		{
 			switch(event->keyval)
