@@ -24,6 +24,7 @@
 
 #include "defines.include"
 #include "gui.h"
+#include "learn.h"
 #include "messages-table.h"
 #include "messages.h"
 #include "message.h"
@@ -98,6 +99,12 @@ typedef struct
 	gchar	*translated;
 } GtrMessagesTableColors;
 
+/*
+ * A new kind of popup menu for our beloved messages table.
+ */
+static gint tree_popup_menu(ETree *tree, int row, ETreePath path, int column,
+	GdkEvent *event);
+
 /*
  * Global variables
  */
@@ -119,6 +126,71 @@ GtrMessagesTableColors *messages_table_colors;
  */
 GHashTable *hash_table=NULL;	
 
+/*
+ * Pops up on a right click in the messages table -- should show any found 
+ *  translation from the learn buffer.
+ */
+static gint tree_popup_menu(ETree *tree, int row, ETreePath path, int column,
+	GdkEvent *event)
+{
+	if(event->button.button==3)
+	{
+		GtrMsg *message=NULL;
+
+		message=e_tree_memory_node_get_data(tree_memory, path);
+
+		/*
+		 * Check if we're on an untranslated message before operating 
+		 *  any further.
+		 */
+		if(message && message->msgid && !message->msgstr)
+		{
+			GtkWidget	*menu=NULL;
+			GtkWidget 	*menu_item=NULL;
+			gchar		*found_str=NULL;
+			
+			/*
+			 * Query our own, personal learn buffer for the 
+			 *  original message string.
+			 */
+			found_str=gtranslator_learn_get_learned_string(message->msgid);
+
+			menu=gtk_menu_new();
+			
+			if(found_str)
+			{
+				GtkWidget	*explanatory_menu_item=NULL;
+
+				explanatory_menu_item=gtk_menu_item_new_with_label(_("Appropriate match:"));
+				gtk_widget_show(explanatory_menu_item);
+				gtk_menu_append(GTK_MENU(menu), explanatory_menu_item);
+
+				menu_item=gtk_menu_item_new_with_label(found_str);
+			}
+			else
+			{
+				menu_item=gtk_menu_item_new_with_label(_("Found nothing appropriate in the personal learn buffer."));
+
+			}
+
+			/*
+			 * Show the menu items.
+			 */
+			gtk_widget_show(menu_item);
+			gtk_menu_append(GTK_MENU(menu), menu_item);
+			
+			/*
+			 * Perform our popup menu action.
+			 */
+			gtk_menu_popup(GTK_MENU(menu), NULL, NULL,
+					NULL, NULL, event->button.button,
+					event->button.time);
+		}
+	}
+
+	return TRUE;
+}
+
 /*
  * Initialize and set up the generally used messages table colors.
  */
@@ -391,7 +463,14 @@ static void *value_at_function(ETreeModel *model, ETreePath path, int column,
 	case COL_TRANSLATION:
 		if(message->msgstr)
 		{
-			return gtranslator_utf8_get_utf8_string(&message->msgstr);
+			if(po->utf8)
+			{
+				return message->msgstr;
+			}
+			else
+			{
+				return gtranslator_utf8_get_utf8_string(&message->msgstr);
+			}
 		}
 		else
 		{
@@ -458,7 +537,7 @@ static gchar *return_string_for_value_function(ETreeModel *model, int column,
 	case COL_NUMBER:
 	case COL_BOLD:
 	case COL_LINE:
-		return g_strdup_printf("%d", (gint) value);
+		return g_strdup_printf("%d", GPOINTER_TO_INT(value));
 		break;
 	default:
 		g_assert_not_reached ();
@@ -598,6 +677,9 @@ GtkWidget *gtranslator_messages_table_new()
 	gtk_signal_connect(GTK_OBJECT(tree), "cursor_activated",
 		GTK_SIGNAL_FUNC(row_selected), NULL);
 	
+	gtk_signal_connect(GTK_OBJECT(tree), "right_click",
+		GTK_SIGNAL_FUNC(tree_popup_menu), NULL);
+	
 	return messages_tree;
 }
 
@@ -628,7 +710,7 @@ void gtranslator_messages_table_clear(void)
 void gtranslator_messages_table_create (void)
 {
 	GList *list;
-	gint i=0;
+	gint i=0, j=0, k=0;
 	
 	if(!file_opened)
 		return;
@@ -664,11 +746,13 @@ void gtranslator_messages_table_create (void)
 		switch (message->status){
 		case GTR_MSG_STATUS_UNKNOWN:
 			node=e_tree_memory_node_insert(tree_memory, unknown_node,
-			0, message);
+			i, message);
+			i++;
 			break;
 		case GTR_MSG_STATUS_TRANSLATED:
 			node=e_tree_memory_node_insert(tree_memory, translated_node,
-			0, message);
+			j, message);
+			j++;
 			break;
 		case GTR_MSG_STATUS_STICK:
 			node=NULL;
@@ -676,14 +760,14 @@ void gtranslator_messages_table_create (void)
 		case GTR_MSG_STATUS_FUZZY:
 		default:
 			node=e_tree_memory_node_insert(tree_memory, fuzzy_node,
-			0, message);
+			k, message);
+			k++;
 		}
 		/*node=e_tree_memory_node_insert(tree_memory, root_node,
 			i, message);*/
 		if (node)
 			g_hash_table_insert(hash_table, message, node); 
 		list = g_list_next(list);
-		i++;
 	}
 }
 
