@@ -42,7 +42,7 @@
 #include "parse.h"
 #include "prefs.h"
 #include "runtime-config.h"
-#include "save-differently.h"
+#include "save.h"
 #include "sidebar.h"
 #include "translator.h"
 #include "undo.h"
@@ -69,7 +69,6 @@
 GtrPo *po;
 gboolean file_opened;
 gboolean message_changed;
-GnomeRegexCache *rxc;
 guint autosave_source_tag=1;
 
 /*
@@ -109,6 +108,8 @@ static void append_line(gchar ** old, const gchar * tail)
 			s++;
 			if (tail[s] == 'n')
 				to_add[d++] = '\n';
+			else if(tail[s] == 'r')
+				to_add[d++] = '\r';
 			else if (tail[s] == 't')
 				to_add[d++] = '\t';
 			else if ((tail[s] == '"') || (tail[s] == '\\'))
