@@ -54,7 +54,8 @@ static void gtranslator_preferences_dialog_help(GtkWidget  * widget, gpointer us
  */
 static GtkWidget 
 	*first_page, *second_page, *third_page, *fourth_page,
-	*fifth_page, *sixth_page, *seventh_page, *eighth_page;
+	*fifth_page, *sixth_page, *seventh_page, *eighth_page,
+	*ninth_page;
 
 /*
  * The entries:
@@ -75,13 +76,19 @@ static GtkWidget
 	*instant_spell_checking, *keep_obsolete, *defaultdomain,
 	*autosave, *autosave_with_suffix, *sweep_compile_file,
 	*use_learn_buffer, *show_messages_table, *rambo_function,
-	*use_own_mt_colors, *collapse_translated_entries;
+	*use_own_mt_colors, *collapse_translated_entries, *auto_learn,
+	*fuzzy_matching, *load_backends, *show_comment;
 
 /*
  * The timeout GtkSpinButton:
  */
+#ifdef YES_WE_ARE_RICH_BEATIFUL_AND_SO_ON
+static GtkWidget
+	*autosave_timeout, *max_history_entries, *min_match_percentage;
+#else
 static GtkWidget
 	*autosave_timeout, *max_history_entries;
+#endif
 
 /*
  * Font/color specific widgets used in the preferences box.
@@ -116,9 +123,9 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	second_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
 		5, 2, _("Language settings"));
 	third_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
-		5, 1, _("Po file editing"));
+		4, 1, _("Po file editing"));
 	fourth_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
-		8, 1, _("Miscellaneous"));
+		9, 1, _("Miscellaneous"));
 	fifth_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
 		4, 2, _("Recent files & spell checking"));
 	sixth_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
@@ -127,6 +134,8 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 		4, 2, _("Autosaving"));
 	eighth_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
 		6, 2, _("Messages table"));
+	ninth_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
+		4, 2, _("Learn buffer & autotranslation"));
 	
 	/*
 	 * Create all the personal entries.
@@ -203,12 +212,8 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	    gtranslator_utils_attach_toggle_with_label(third_page, 3,
 		_("Warn me if I'm trying to save an unchanged file"),
 		GtrPreferences.warn_if_no_change, gtranslator_preferences_dialog_changed);
-	use_learn_buffer =
-	    gtranslator_utils_attach_toggle_with_label(third_page, 4,
-	    	_("Also query the personal learn buffer while autotranslating untranslated messages"),
-		GtrPreferences.use_learn_buffer, gtranslator_preferences_dialog_changed);
 	keep_obsolete =
-	    gtranslator_utils_attach_toggle_with_label(third_page, 5,
+	    gtranslator_utils_attach_toggle_with_label(third_page, 4,
 		_("Keep obsolete message in the po files"),
 		GtrPreferences.keep_obsolete, gtranslator_preferences_dialog_changed);
 
@@ -227,21 +232,27 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	rambo_function=gtranslator_utils_attach_toggle_with_label(fourth_page, 4,
 		_("Enable the functionality to remove all translations from a po file"),
 		GtrPreferences.rambo_function, gtranslator_preferences_dialog_changed);
-	sweep_compile_file=gtranslator_utils_attach_toggle_with_label(fourth_page, 5,
-		_("Delete compiled files (e.g. \"project.gmo\")"),
+	sweep_compile_file=gtranslator_utils_attach_toggle_with_label(fourth_page,
+		5, _("Delete compiled files (e.g. \"project.gmo\")"),
 		GtrPreferences.sweep_compile_file, gtranslator_preferences_dialog_changed);
-	save_geometry_tb=gtranslator_utils_attach_toggle_with_label(fourth_page, 6,
-		_("Save geometry on exit & restore it on startup"),
+	load_backends=gtranslator_utils_attach_toggle_with_label(fourth_page,
+		6, _("Load all backends on startup"),
+		GtrPreferences.load_backends, gtranslator_preferences_dialog_changed);
+	save_geometry_tb=gtranslator_utils_attach_toggle_with_label(fourth_page,
+		7, _("Save geometry on exit & restore it on startup"),
 		GtrPreferences.save_geometry, gtranslator_preferences_dialog_changed);
-	show_sidebar=gtranslator_utils_attach_toggle_with_label(fourth_page, 7,
-		_("Show the views sidebar"),
+	show_comment=gtranslator_utils_attach_toggle_with_label(fourth_page,
+		8, _("Show instant comment view in the main pane"),
+		GtrPreferences.show_comment, gtranslator_preferences_dialog_changed);
+	show_sidebar=gtranslator_utils_attach_toggle_with_label(fourth_page,
+		9, _("Show the views sidebar"),
 		GtrPreferences.show_sidebar, gtranslator_preferences_dialog_changed);
 	
 	/*
 	 * The fifth page with the Recent files options.
 	 */
 	max_history_entries=gtranslator_utils_attach_spin_with_label(fifth_page, 0, 
-		_("Maximum number of recent files shown in the recent files' list:"), 3, 15, 
+		_("Maximum number of entries in the recent files' list:"), 3, 15, 
 		GtrPreferences.max_history_entries, gtranslator_preferences_dialog_changed);
 	
 	check_recent_files=gtranslator_utils_attach_toggle_with_label(fifth_page, 1,
@@ -254,8 +265,9 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 		_("Use special dictionary"),
 		GtrPreferences.use_own_dict, gtranslator_preferences_dialog_changed);
 	dictionary_file=
-	    gtranslator_utils_attach_entry_with_label(fifth_page, 4, _("Dictionary to use:"),
-				    GtrPreferences.dictionary, gtranslator_preferences_dialog_changed);
+	    gtranslator_utils_attach_entry_with_label(fifth_page, 4, 
+	    	_("Dictionary to use:"),
+	        GtrPreferences.dictionary, gtranslator_preferences_dialog_changed);
 	
 	/*
 	 * The sixth page with the special font/color stuff.
@@ -371,6 +383,31 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 		_("Translated entries color:"), _("gtranslator -- translated entries' color"),
 		COLOR_MESSAGES_TABLE_TRANSLATED, gtranslator_preferences_dialog_changed);
 
+	/*
+	 * Learn buffer/auto translation options go now into their own prefs page ,-)
+	 */
+	use_learn_buffer =
+	    gtranslator_utils_attach_toggle_with_label(ninth_page, 0,
+	    	_("Also query the personal learn buffer while autotranslating untranslated messages"),
+		GtrPreferences.use_learn_buffer, gtranslator_preferences_dialog_changed);
+    	auto_learn =
+	    gtranslator_utils_attach_toggle_with_label(ninth_page, 1,
+	    	_("Automatically learn a newly translated message"),
+		GtrPreferences.auto_learn, gtranslator_preferences_dialog_changed);
+	fuzzy_matching=gtranslator_utils_attach_toggle_with_label(ninth_page,
+		/*
+		 * Translators: With "fuzzy" I mean a more enhanced (and more
+		 *  crappy) logic while searching for appropriate translations
+		 *   for a original string.
+		 */
+		2, _("Use \"fuzzy\" matching routines for the learn buffer queries"),
+		GtrPreferences.fuzzy_matching, gtranslator_preferences_dialog_changed);
+#ifdef YES_WE_ARE_RICH_BEATIFUL_AND_SO_ON
+	min_match_percentage=gtranslator_utils_attach_spin_with_label(ninth_page,
+		3, _("Minimal required similarity percentage while doing autotranslation"),
+		25, 100, GtrPreferences.min_match_percentage, gtranslator_preferences_dialog_changed);
+#endif
+
 	/*
 	 * Connect the signals to the preferences box.
 	 */
@@ -476,6 +513,7 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 	GtrPreferences.popup_menu = if_active(enable_popup_menu);
 	GtrPreferences.sweep_compile_file = if_active(sweep_compile_file);
 	GtrPreferences.show_sidebar = if_active(show_sidebar);
+	GtrPreferences.show_comment = if_active(show_comment);
 	GtrPreferences.collapse_translated = if_active(collapse_translated_entries);
 	GtrPreferences.check_recent_file = if_active(check_recent_files);
 	GtrPreferences.instant_spell_check = if_active(instant_spell_checking);
@@ -484,6 +522,9 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 	GtrPreferences.use_own_mt_colors = if_active(use_own_mt_colors);
 	GtrPreferences.use_own_dict = if_active(use_own_dict);
 	GtrPreferences.use_learn_buffer = if_active(use_learn_buffer);
+	GtrPreferences.fuzzy_matching = if_active(fuzzy_matching);
+	GtrPreferences.load_backends = if_active(load_backends);
+	GtrPreferences.auto_learn = if_active(auto_learn);
 	GtrPreferences.keep_obsolete = if_active(keep_obsolete);
 	GtrPreferences.autosave = if_active(autosave);
 	GtrPreferences.autosave_with_suffix = if_active(autosave_with_suffix);
@@ -517,6 +558,12 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 		gtk_spin_button_get_value_as_float(GTK_SPIN_BUTTON(
 			max_history_entries));
 	
+	#ifdef YES_WE_ARE_RICH_BEATIFUL_AND_SO_ON
+	GtrPreferences.min_match_percentage =
+		gtk_spin_button_get_value_as_float(GTK_SPIN_BUTTON(
+			min_match_percentage));
+	#endif
+	
 	gtranslator_config_set_string("dict/file", GtrPreferences.dictionary);
 	gtranslator_config_set_string("informations/autosave_suffix", 
 		GtrPreferences.autosave_suffix);
@@ -527,6 +574,11 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 	gtranslator_config_set_float("informations/max_history_entries", 
 		GtrPreferences.max_history_entries);
 	
+	#ifdef YES_WE_ARE_RICH_BEATIFUL_AND_SO_ON
+	gtranslator_config_set_float("informations/min_match_percentage",
+		GtrPreferences.min_match_percentage);
+	#endif
+	
 	GTR_FREE(GtrPreferences.msgid_font);
 	GTR_FREE(GtrPreferences.msgstr_font);
 	
@@ -555,19 +607,23 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 	{
 		/*
 		 * First check if there's such a colorscheme in 
-		 *  ~/.gtranslator/colorschemes before checking the global directory.
+		 *  ~/.gtranslator/colorschemes before checking the global 
+		 *   colorschemes directory.
 		 */
-		GtrPreferences.scheme=g_strdup_printf("%s/.gtranslator/colorschemes/%s.xml",
-			g_get_home_dir(), selected_scheme_file);
+		GtrPreferences.scheme=g_strdup_printf(
+			"%s/.gtranslator/colorschemes/%s.xml",
+				g_get_home_dir(), 
+				selected_scheme_file);
 
 		/*
-		 * If there's no such colorscheme in the ~/.gtranslator/colorschemes
-		 *  directory try the global directory.
+		 * If there's no such colorscheme in the 
+		 *  ~/.gtranslator/colorschemes directory, try the global 
+		 *   colorschemes directory.
 		 */
 		if(!g_file_exists(GtrPreferences.scheme))
 		{
-			GtrPreferences.scheme=g_strdup_printf("%s/%s.xml", SCHEMESDIR,
-				selected_scheme_file);
+			GtrPreferences.scheme=g_strdup_printf("%s/%s.xml", 
+				SCHEMESDIR, selected_scheme_file);
 		}
 	    
 		if(g_file_exists(GtrPreferences.scheme))
@@ -623,6 +679,8 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 			      GtrPreferences.popup_menu);
 	gtranslator_config_set_bool("toggles/show_sidebar",
 			      GtrPreferences.show_sidebar);
+	gtranslator_config_set_bool("toggles/show_comment",
+			      GtrPreferences.show_comment);
 	gtranslator_config_set_bool("toggles/rambo_function",
 			      GtrPreferences.rambo_function);
 	gtranslator_config_set_bool("toggles/check_recent_files",
@@ -639,6 +697,12 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 			      GtrPreferences.use_own_dict);
 	gtranslator_config_set_bool("toggles/use_learn_buffer",
 			      GtrPreferences.use_learn_buffer);
+	gtranslator_config_set_bool("toggles/fuzzy_matching",
+			      GtrPreferences.fuzzy_matching);
+	gtranslator_config_set_bool("toggles/load_backends",
+			      GtrPreferences.load_backends);
+	gtranslator_config_set_bool("toggles/auto_learn",
+			      GtrPreferences.auto_learn);
 	gtranslator_config_set_bool("toggles/collapse_translated_entries",
 			      GtrPreferences.collapse_translated);
 	gtranslator_config_set_bool("toggles/keep_obsolete",
@@ -667,6 +731,14 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 	{
 		gtranslator_sidebar_hide();
 	}
+
+	/*
+	 * Hide the comment viewing (area) via our new util function.
+	 */
+	if(!GtrPreferences.show_comment)
+	{
+		gtranslator_comment_hide();
+	}
 }
 
 /*
@@ -751,6 +823,26 @@ void gtranslator_preferences_read(void)
 
 	GtrPreferences.max_history_entries =
 		gtranslator_config_get_float("informations/max_history_entries");
+	#ifdef YES_WE_ARE_RICH_BEATIFUL_AND_SO_ON
+	GtrPreferences.min_match_percentage =
+		gtranslator_config_get_float("informations/min_match_percentage");
+	#endif
+
+	/*
+	 * Check some prefs values for sanity and set sane values if no really
+	 *  good prefs values have been detected.
+	 */
+	#ifdef YES_WE_ARE_RICH_BEATIFUL_AND_SO_ON
+	if(GtrPreferences.min_match_percentage < 25.0)
+	{
+		GtrPreferences.min_match_percentage=25.0;
+	}
+	#endif
+
+	if(GtrPreferences.autosave_timeout < 1.0)
+	{
+		GtrPreferences.autosave_timeout=1.0;
+	}
 
 	GtrPreferences.instant_spell_check = 
 		gtranslator_config_get_bool("toggles/instant_spell_check");
@@ -789,6 +881,12 @@ void gtranslator_preferences_read(void)
 
 	GtrPreferences.use_learn_buffer = gtranslator_config_get_bool(
 		"toggles/use_learn_buffer");
+	GtrPreferences.fuzzy_matching = gtranslator_config_get_bool(
+		"toggles/fuzzy_matching");
+	GtrPreferences.load_backends = gtranslator_config_get_bool(
+		"toggles/load_backends");
+	GtrPreferences.auto_learn = gtranslator_config_get_bool(
+		"toggles/auto_learn");
 	GtrPreferences.match_case = gtranslator_config_get_bool(
 		"find/case_sensitive");
 	GtrPreferences.find_in = gtranslator_config_get_int("find/find_in");
@@ -798,6 +896,8 @@ void gtranslator_preferences_read(void)
 		"toggles/fill_header");
 	GtrPreferences.show_sidebar = gtranslator_config_get_bool(
 		"toggles/show_sidebar");
+	GtrPreferences.show_comment = gtranslator_config_get_bool(
+		"toggles/show_comment");
 	GtrPreferences.show_messages_table = gtranslator_config_get_bool(
 		"toggles/show_messages_table");
 	GtrPreferences.collapse_translated = gtranslator_config_get_bool(
