@@ -61,6 +61,8 @@ void gtranslator_preferences_init_default_values()
 		gtranslator_config_set_bool("toggles/keep_obsolete", TRUE);
 		gtranslator_config_set_bool("toggles/sweep_compile_file", FALSE);
 		gtranslator_config_set_bool("toggles/use_learn_buffer", TRUE);
+		gtranslator_config_set_bool("toggles/fuzzy_matching", FALSE);
+		gtranslator_config_set_bool("toggles/load_backends", TRUE);
 		
 		/*
 		 * GUI related default values.
@@ -69,6 +71,7 @@ void gtranslator_preferences_init_default_values()
 		gtranslator_config_set_bool("toggles/use_dot_char", TRUE);
 		gtranslator_config_set_bool("toggles/show_sidebar", TRUE);
 		gtranslator_config_set_bool("toggles/show_messages_table", TRUE);
+		gtranslator_config_set_bool("toggles/show_comment", TRUE);
 		gtranslator_config_set_bool("toggles/collapse_translated_entries", TRUE);
 		gtranslator_config_set_bool("toggles/enable_popup_menu", TRUE);
 		gtranslator_config_set_bool("toggles/use_update_function", TRUE);
@@ -102,6 +105,11 @@ void gtranslator_preferences_init_default_values()
 		 */
 		gtranslator_config_set_float("informations/max_history_entries", 10.0);
 
+		/*
+		 * Set the required minimum match percentage to 75% as default.
+		 */
+		gtranslator_config_set_float("informations/min_match_percentage", 75.0);
+
 		/*
 		 * On the first startup we don't have got any history yet.
 		 */
