@@ -30,6 +30,7 @@
 #include "translator.h"
 #include "utils.h"
 
+#include <ctype.h>
 #include <dirent.h>
 #include <unistd.h>
 
@@ -104,7 +105,7 @@ gchar *gtranslator_utils_strip_all_punctuation_chars(const gchar *str)
 		'?', '!', '(', ')',
 		'[', ']', '{', '}',
 		'`', '\'', '^', '/',
-		'\\', '<', '>', -1
+		'\\', '<', '>', 1
 	};
 
 	g_return_val_if_fail(str!=NULL, NULL);
@@ -118,7 +119,7 @@ gchar *gtranslator_utils_strip_all_punctuation_chars(const gchar *str)
 	 * Now strip out all these special characters to get a more raw
 	 *  string (could result in better results for matching).
 	 */
-	while(punctuation_characters[index]!=-1)
+	while((gint) punctuation_characters[index]!=1)
 	{
 		stripped_string=nautilus_str_strip_chr(stripped_string,
 			punctuation_characters[index]);
@@ -402,10 +403,10 @@ gboolean gtranslator_utils_autosave(gpointer foo_me_or_die)
 void gtranslator_utils_get_compile_file_names(gchar **test_file, 
 	gchar **output_file, gchar **result_file)
 {
-	*test_file=g_strdup_printf("%s/.gtranslator/gtranslator-temp-compile-file",
+	*test_file=g_strdup_printf("%s/.gtranslator/files/gtranslator-temp-compile-file",
 		g_get_home_dir());
 
-	*result_file=g_strdup_printf("%s/.gtranslator/gtranslator-compile-result-file",
+	*result_file=g_strdup_printf("%s/.gtranslator/files/gtranslator-compile-result-file",
 		g_get_home_dir());
 
 	*output_file=g_strdup_printf("%s/%s.gmo",
@@ -582,6 +583,60 @@ void gtranslator_utils_free_list(GList *list, gboolean free_contents)
 	}
 }
 
+/*
+ * Some voodoo-alike functions have been missing in gtranslator, so here we
+ *  go: calculates a similarity percentage based on really insane logic.
+ */
+gfloat gtranslator_utils_calculate_similarity(const gchar *a, const gchar *b)
+{
+	gfloat	similarity;
+	gfloat	one_char_percentage;
+	
+	gint	i=0;
+
+	similarity=one_char_percentage=0.0;
+
+	/*
+	 * Eh, check for these quite useless situations in the two gchars.
+	 */
+	if(!a || !b || !nautilus_strcmp(a, "") || !nautilus_strcmp(b, ""))
+	{
+		return 0.0;
+	}
+
+	/*
+	 * Calculate the similarity value a single char is representing.
+	 */
+	if(strlen(a) > strlen(b))
+	{
+		one_char_percentage=(100 / (strlen(a) - 1));
+	}
+	else
+	{
+		one_char_percentage=(100 / (strlen(b) - 1));
+	}
+
+	/*
+	 * Now we do check the characters of the two given strings..
+	 *  Voodoo, Magic!
+	 */
+	while(a[i] && b[i] && a[i]!='\0' && b[i]!='\0')
+	{
+		if(a[i]==b[i])
+		{
+			similarity+=one_char_percentage;
+		}
+		else if(tolower(a[i])==tolower(b[i]))
+		{
+			similarity+=(one_char_percentage / 2);
+		}
+		
+		i++;
+	}
+
+	return similarity;
+}
+
 /*
  * Check for matching of an entry of the list entry and the string -- returns
  *  '-1' on non-matching, else the position in the list.
@@ -715,11 +770,11 @@ void gtranslator_utils_language_lists_create(void)
 			    g_list_prepend(group_emails_list,
 					   (gpointer) languages[c].group_email);
 		if (g_list_find_custom
-		    (bits_list, (gpointer) languages[c].bits,
+		    (bits_list, GINT_TO_POINTER(languages[c].bits),
 		     (GCompareFunc) strcmp) == NULL)
 			bits_list =
 			    g_list_prepend(bits_list,
-					   (gpointer) languages[c].bits);
+					   GINT_TO_POINTER(languages[c].bits));
 		c++;
 	}
 	/*
